@@ -1,4 +1,4 @@
-const loader = require('./index');
+const loader = require("./index");
 
 module.exports = loader.default;
 module.exports.pitch = loader.pitch;
